#include <QMessageBox>
#include <QSettings>
#include <QProcess>

#include <klocalizedstring.h>

#include <packagemanager.h>

#include "hpplugins.h"

const QString hplipPackage = QStringLiteral("hplip");

HPPlugins::HPPlugins() : KSaneHPPlugins()
{

}

bool HPPlugins::checkPlugins()
{
    const QString hplipVersion = findHplipPackage();

    if (hplipVersion.isEmpty()) {
        installHplip();
        return false;
    }

    const QString hppluginsVersion = findHPPlugins();

    if (hppluginsVersion.isEmpty() || hplipVersion.indexOf(hppluginsVersion) != 0) {
        installHPPlugins();
        return false;
    }

    return true;
}

QString HPPlugins::findHplipPackage()
{    
    if (FlyAdmin::PackageManager::isPackageInstalled(hplipPackage))
        return FlyAdmin::PackageManager::getInstalledPackagesVersions(hplipPackage).first();

    return QString();
}

void HPPlugins::installHplip()
{
    auto answer = QMessageBox::warning(nullptr, i18n("Warning"),
                         i18n("You need to install %1 package for correct work with HP scanner.\n"
                              "Do you want to install %1 package now?", hplipPackage),
                         QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);

    if ((answer == QMessageBox::Yes)
        && !FlyAdmin::PackageManager::runSynapticWithPackageSelected(hplipPackage)) {
        QMessageBox::critical(nullptr, i18n("Error"),
                                       i18n("Synaptic failed to start. Try updating %1 package manually.", hplipPackage));
    }
}

QString HPPlugins::findHPPlugins()
{
    QSettings hplipState(QStringLiteral("/var/lib/hp/hplip.state"), QSettings::IniFormat);

    return hplipState.value(QStringLiteral("plugin/version"), QString()).toString();
}

void HPPlugins::installHPPlugins()
{
    auto answer = QMessageBox::warning(nullptr, i18n("Warning"),
                         i18n("You need to install HP plugins for correct work with HP scanner.\n"
                              "Do you want to install HP plugins now?"),
                         QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);

    if (answer == QMessageBox::Yes)
        QProcess::startDetached(QStringLiteral("hp-plugin"), QStringList());
}
