#ifndef PAGEITEMDELEGATE_H
#define PAGEITEMDELEGATE_H

#include <QObject>
#include <QStyledItemDelegate>

class QAbstractItemView;
class QToolButton;

class PageItemDelegate : public QStyledItemDelegate
{
Q_OBJECT

public:
    PageItemDelegate(QAbstractItemView *view, QObject *parent = nullptr);

    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;

    bool eventFilter(QObject *object, QEvent *event) override;

    void setOcrEnabled(bool enabled);

private:
    void initButtons();

    bool hoverEventFilter(QHoverEvent *event);
    void updateHoverUi(const QModelIndex &index);
    void showContextBar(const QRect &rect);

signals:
    void savePage(int number);
    void recognizePage(int number);
    void rotateLeftPage(int number);
    void rotateRightPage(int number);
    void horizontalMirror(int number);
    void verticalMirror(int number);
    void moveUpPage(int number);
    void moveDownPage(int number);
    void removePage(int number);
    void showFileWithPage(const QString &filePath);

private:
    QAbstractItemView *m_view { nullptr };
    QWidget *m_contextBar { nullptr };

    QToolButton *m_showFileButton;
    QToolButton *m_recognizeButton;

    QModelIndex m_indexUnderCursor;
};

#endif // PAGEITEMDELEGATE_H
