#ifndef PAGESMODEL_H
#define PAGESMODEL_H

#include <QAbstractListModel>
#include <QImage>

#include "ksanepage.h"

class PagesModel : public QAbstractListModel
{
    Q_OBJECT

public:
    explicit PagesModel(QObject *parent = nullptr);

    // Basic functionality:
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;       

    Qt::ItemFlags flags(const QModelIndex& index) const override;

    bool moveRows(const QModelIndex &sourceParent, int sourceRow, int count, const QModelIndex &destinationParent, int destinationChild) override;
    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;

    bool canDropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) const override;
    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
    QMimeData *	mimeData(const QModelIndexList &indexes) const override;
    QStringList	mimeTypes() const override;
    Qt::DropActions	supportedDropActions() const override;

    void setMovePagesEnabled(bool enabled);

    void addPage(const KSanePagePointer &page);
    KSanePagePointer page(int pageNumber);
    void changePage(int pageNumber, const KSanePagePointer &page);
    QList<KSanePagePointer> allPages();

    void removePage(const QModelIndex &index);
    void removePages(const QModelIndexList &indexes);
    void removeAllPages();

private:
    QList<KSanePagePointer> m_pages;
    Qt::DropAction m_dropAction;
};

#endif // PAGESMODEL_H
