#ifndef PAGESWIDGET_H
#define PAGESWIDGET_H

#include <QItemSelection>

#include <ksanepageswidget.h>

namespace Ui {
class PagesWidget;
}

class PagesModel;
class PageItemDelegate;

class PagesWidget : public KSanePagesWidget
{
    Q_OBJECT

public:
    explicit PagesWidget(QWidget *parent = nullptr);
    ~PagesWidget();

    void addPage(const KSanePagePointer &page) override;
    QList<KSanePagePointer> pages() override;

    void setOcrEnabled(bool enabled) override;

private:
    void initActions();
    void initPageDelegate();

    QList<KSanePagePointer> pages(const QModelIndexList &indexes);
    QList<KSanePagePointer> selectedPages();
    QList<int> pageNumbers(const QModelIndexList &indexes);
    QList<int> selectedPageNumbres();

    void rotatePage(int number, qreal angle);
    void rotateSelectedPages(qreal angle);

    void mirrorPage(int number, bool horizontal, bool vertical);
    void mirrorSelectedPages(bool horizontal, bool vertical);

public Q_SLOTS:
    void rotateCurrentPageLeft() override;
    void rotateCurrentPageRight() override;
    void horizontalMirrorCurrentPage() override;
    void verticalMirrorCurrentPage() override;
    void removeCurrentPage() override;
    void saveCurrentPage() override;
    void recognizeCurrentPage() override;
    void clipCurrentPage(const QRectF &rect) override;

private Q_SLOTS:
    void rotateLeftPage(int number);
    void rotateRightPage(int number);
    void horizontalMirror(int number);
    void verticalMirror(int number);
    void moveUpPage(int number);
    void moveUpCurrentPage();
    void moveDownPage(int number);
    void moveDownCurrentPage();
    void savePage(int number);
    void saveSelectedPages();   
    void saveAllPages();
    void recognizePage(int number);
    void recognizeSelectedPages();
    void recognizeAllPages();
    void removePage(int number);
    void removeSelectedPages();
    void removeAllPages();
    void currentIndexChanged(const QModelIndex &index);
    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);

private:
    Ui::PagesWidget *m_ui;
    PagesModel *m_pagesModel;
    PageItemDelegate *m_pageDelegate;
};

#endif // PAGESWIDGET_H
